@@ -113,6 +113,8 @@ tab_df <- function(x,
   # get style definition
   style <- tab_df_style(CSS = CSS, ...)
 
+  rnames <- row.names(x)
+
   x <- as.data.frame(lapply(x, function(.i) {
     if (is.numeric(.i) && sjmisc::is_float(.i))
       sprintf("%.*f", digits, .i)
@@ -132,6 +134,7 @@ tab_df <- function(x,
       altr.row.col = alternate.rows,
       sort.column = sort.column,
       include.table.tag = TRUE,
+      rnames = rnames,
       ...
     )
 
@@ -285,6 +288,7 @@ tab_model_df <- function(x,
                          col.header = NULL,
                          show.re.var = FALSE,
                          show.icc = FALSE,
+                         digits.rsq = 3,
                          digits.re = 2,
                          encoding = "UTF-8",
                          CSS = NULL,
@@ -509,6 +513,8 @@ tab_model_df <- function(x,
 
       }
     }
+    page.content <- paste0(page.content, "  </tr>\n")
+
 
 
     # random effects: Between-group-variance: tau.00 ----
@@ -716,10 +722,12 @@ tab_model_df <- function(x,
         page.content <- paste0(
           page.content,
           sprintf(
-            "    <td class=\"%s\" colspan=\"%i\">%.3f / %.3f</td>\n",
+            "    <td class=\"%s\" colspan=\"%i\">%.*f / %.*f</td>\n",
             s_css,
             as.integer(colspan),
+            digits.rsq,
             rsq.list[[i]][[1]],
+            digits.rsq,
             rsq.list[[i]][[2]]
           )
         )
@@ -729,9 +737,10 @@ tab_model_df <- function(x,
         page.content <- paste0(
           page.content,
           sprintf(
-            "    <td class=\"%s\" colspan=\"%i\">%.3f</td>\n",
+            "    <td class=\"%s\" colspan=\"%i\">%.*f</td>\n",
             s_css,
             as.integer(colspan),
+            digits.rsq,
             rsq.list[[i]][[1]]
           )
         )
