@@ -20,15 +20,23 @@
 #'    be removed from the output Counterpart to \code{terms}. \code{rm.terms =
 #'    "t_name"} would remove the term \emph{t_name}. Default is \code{NULL}, i.e.
 #'    all terms are used. For factors, levels that should be removed from the plot
-#'    need to be explicitely indicated in square brackets, and match the model's
+#'    need to be explicitly indicated in square brackets, and match the model's
 #'    coefficient names, e.g. \code{rm.terms = "t_name [2,3]"} would remove the terms
 #'    \code{"t_name2"} and \code{"t_name3"} (assuming that the variable \code{t_name}
 #'    was categorical and has at least the factor levels \code{2} and \code{3}).
+#' @param keep,drop Character containing a regular expression pattern that
+#'   describes the parameters that should be included (for \code{keep}) or excluded
+#'   (for \code{drop}) in the returned data frame. \code{keep} may also be a
+#'   named list of regular expressions. All non-matching parameters will be
+#'   removed from the output. If \code{keep} has more than one element, these
+#'   will be merged with an \code{OR} operator into a regular expression pattern
+#'   like this: \code{"(one|two|three)"}. See further details in
+#'   \code{?parameters::model_parameters}.
 #' @param pred.labels Character vector with labels of predictor variables.
 #'    If not \code{NULL}, \code{pred.labels} will be used in the first
 #'    table column with the predictors' names. By default, if \code{auto.label = TRUE}
 #'    and \href{https://strengejacke.github.io/sjlabelled/articles/intro_sjlabelled.html}{data is labelled},
-#'    \code{\link[sjlabelled]{get_term_labels}} is called to retrieve the labels
+#'    \code{\link[sjlabelled]{term_labels}} is called to retrieve the labels
 #'    of the coefficients, which will be used as predictor labels. If data is
 #'    not labelled, \href{https://easystats.github.io/parameters/reference/format_parameters.html}{format_parameters()}
 #'    is used to create pretty labels. If \code{pred.labels = ""} or \code{auto.label = FALSE}, the raw
@@ -39,7 +47,8 @@
 #'    related predictor in the table, no matter in which way the predictors
 #'    are sorted. See 'Examples'.
 #' @param dv.labels Character vector with labels of dependent variables of all
-#'    fitted models. See 'Examples'.
+#'    fitted models. If \code{dv.labels = ""}, the row with names of dependent
+#'    variables is omitted from the table.
 #' @param show.intercept Logical, if \code{TRUE}, the intercepts are printed.
 #' @param show.est Logical, if \code{TRUE}, the estimates are printed.
 #' @param show.zeroinf Logical, if \code{TRUE} and model has a zero-inflated
@@ -63,7 +72,9 @@
 #' @param show.se Logical, if \code{TRUE}, the standard errors are
 #'   also printed. If robust standard errors are required, use arguments
 #'   \code{vcov.fun}, \code{vcov.type} and \code{vcov.args} (see
-#'   \code{\link[parameters]{standard_error_robust}} for details).
+#'   \code{\link[parameters]{standard_error_robust}} and
+#'   \href{https://easystats.github.io/parameters/articles/model_parameters_robust.html}{this vignette}
+#'   for details).
 #' @param show.r2 Logical, if \code{TRUE}, the r-squared value is also printed.
 #'    Depending on the model, these might be pseudo-r-squared values, or Bayesian
 #'    r-squared etc. See \code{\link[performance]{r2}} for details.
@@ -84,13 +95,15 @@
 #' @param string.std_se Character vector, used for the column heading of standard error of standardized coefficients. Default is \code{"standardized std. Error"}.
 #' @param string.std_ci Character vector, used for the column heading of confidence intervals of standardized coefficients. Default is \code{"standardized std. Error"}.
 #' @param string.p Character vector, used for the column heading of p values. Default is \code{"p"}.
+#' @param string.std.p Character vector, used for the column heading of p values. Default is \code{"std. p"}.
 #' @param string.df Character vector, used for the column heading of degrees of freedom. Default is \code{"df"}.
 #' @param string.stat Character vector, used for the test statistic. Default is \code{"Statistic"}.
+#' @param string.std.stat Character vector, used for the test statistic. Default is \code{"std. Statistic"}.
 #' @param string.resp Character vector, used for the column heading of of the response level for multinominal or categorical models. Default is \code{"Response"}.
 #' @param string.intercept Character vector, used as name for the intercept parameter. Default is \code{"(Intercept)"}.
 #' @param strings Named character vector, as alternative to arguments like \code{string.ci}
 #'    or \code{string.p} etc. The name (lhs) must be one of the string-indicator from
-#'    the forementioned arguments, while the value (rhs) is the string that is used
+#'    the aforementioned arguments, while the value (rhs) is the string that is used
 #'    as column heading. E.g., \code{strings = c(ci = "Conf.Int.", se = "std. Err")}
 #'    would be equivalent to setting \code{string.ci = "Conf.Int.", string.se = "std. Err"}.
 #' @param ci.hyphen Character vector, indicating the hyphen for confidence interval range.
@@ -100,6 +113,8 @@
 #' @param emph.p Logical, if \code{TRUE}, significant p-values are shown bold faced.
 #' @param digits Amount of decimals for estimates
 #' @param digits.p Amount of decimals for p-values
+#' @param digits.rsq Amount of decimals for r-squared values
+#' @param digits.re Amount of decimals for random effects part of the summary table.
 #' @param collapse.ci Logical, if \code{FALSE}, the CI values are shown in
 #'    a separate table column.
 #' @param collapse.se Logical, if \code{FALSE}, the SE values are shown in
@@ -114,7 +129,7 @@
 #' @param show.ci50 Logical, if \code{TRUE}, for Bayesian models, a second
 #'    credible interval is added to the table output.
 #' @param bootstrap Logical, if \code{TRUE}, returns bootstrapped estimates..
-#' @param iterations Numeric, number of bootsrap iterations (default is 1000).
+#' @param iterations Numeric, number of bootstrap iterations (default is 1000).
 #' @param seed Numeric, the number of the seed to replicate bootstrapped estimates. If \code{NULL}, uses random seed.
 #' @param show.fstat Logical, if \code{TRUE}, the F-statistics for each model is
 #'    printed in the table summary. This option is not supported by all model types.
@@ -130,29 +145,34 @@
 #'    are only shown in the table when the related argument (like \code{show.est}
 #'    for \code{"estimate"}) is set to \code{TRUE} or another valid value.
 #'    Table columns are printed in the order as they appear in \code{col.order}.
-#' @param p.val Character, for mixed models, indicates how p-values are computed.
-#'   Use \code{p.val = "wald"} for a faster, but less precise computation. For
-#'   \code{p.val = "kenward"} (or \code{p.val = "kr"}), computation of p-values
-#'   is based on conditional F-tests with Kenward-Roger approximation for the
-#'   degrees of freedom. \code{p.val = "satterthwaite"} uses Satterthwaite's
-#'   approximation (see \code{\link[parameters]{dof_kenward}} and \code{\link[parameters]{dof_satterthwaite}}
-#'   for details). In the latter cases, use \code{show.df = TRUE} to show the
-#'   approximated degrees of freedom for each coefficient.
+#' @param df.method,p.val Method for computing degrees of freedom for p-values,
+#'   standard errors and confidence intervals (CI). Only applies to mixed models.
+#'   Use \code{df.method = "wald"} for a faster, but less precise computation.
+#'   This will use the residual degrees of freedom (as returned by \code{df.residual()})
+#'   for linear mixed models, and \code{Inf} degrees if freedom for all other
+#'   model families. \code{df.method = "kenward"} (or \code{df.method = "kr"})
+#'   uses Kenward-Roger approximation for the degrees of freedom.
+#'   \code{df.method = "satterthwaite"} uses Satterthwaite's approximation and
+#'   \code{"ml1"} uses a "m-l-1" heuristic see \code{\link[parameters]{degrees_of_freedom}}
+#'   for details). Use \code{show.df = TRUE} to show the approximated degrees of freedom
+#'   for each coefficient.
 #' @param p.style Character, indicating if p-values should be printed as
-#'   numeric value (\code{"numeric"}), as asterisks (\code{"asterisk"})
-#'   or both (\code{"both"}). May be abbreviated.
+#'   numeric value (\code{"numeric"}), as 'stars' (asterisks) only (\code{"stars"}),
+#'   or scientific (\code{"scientific"}). Scientific and numeric style can be
+#'   combined with "stars", e.g. \code{"numeric_stars"}
 #' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions,
 #'    according to the \href{http://www.w3.org/Style/CSS/}{official CSS syntax}.
 #'    See 'Details' or \href{https://strengejacke.github.io/sjPlot/articles/table_css.html}{this package-vignette}.
 #' @param file Destination file, if the output should be saved as file.
 #'    If \code{NULL} (default), the output will be saved as temporary file and
-#'    openend either in the IDE's viewer pane or the default web browser.
+#'    opened either in the IDE's viewer pane or the default web browser.
 #' @param use.viewer Logical, if \code{TRUE}, the HTML table is shown in the IDE's
 #'    viewer pane. If \code{FALSE} or no viewer available, the HTML table is
 #'    opened in a web browser.
 #'
 #' @inheritParams plot_models
 #' @inheritParams plot_model
+#' @inheritParams tab_df
 #'
 #' @return Invisibly returns
 #'          \itemize{
@@ -173,23 +193,23 @@
 #'         \href{https://strengejacke.github.io/sjPlot/articles/tab_mixed.html}{Summary of Mixed Models as HTML Table} and
 #'         \href{https://strengejacke.github.io/sjPlot/articles/tab_bayes.html}{Summary of Bayesian Models as HTML Table}.
 #'
-#' @details \strong{Standardized Estimates}
-#'    \cr \cr
-#'    Concerning the \code{show.std} argument, \code{show.std = "std"}
-#'    will print normal standardized estimates. For \code{show.std = "std2"},
-#'    however, standardization of estimates follows
-#'    \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
-#'    suggestion, rescaling the estimates by dividing them by two standard
-#'    deviations instead of just one. Resulting coefficients are then
-#'    directly comparable for untransformed binary predictors.
-#'    For backward compatibility reasons, \code{show.std} also may be
-#'    a logical value; if \code{TRUE}, normal standardized estimates are
-#'    printed (same effect as \code{show.std = "std"}). Use
-#'    \code{show.std = NULL} (default) or \code{show.std = FALSE},
-#'    if standardized estimats should not be printed.
-#'    \cr \cr
-#'    \strong{How do I use \code{CSS}-argument?}
-#'    \cr \cr
+#' @details
+#' \subsection{Standardized Estimates}{
+#'   Default standardization is done by completely refitting the model on the
+#'   standardized data. Hence, this approach is equal to standardizing the
+#'   variables before fitting the model, which is particularly recommended for
+#'   complex models that include interactions or transformations (e.g., polynomial
+#'   or spline terms). When \code{show.std = "std2"}, standardization of estimates
+#'   follows \href{http://www.stat.columbia.edu/~gelman/research/published/standardizing7.pdf}{Gelman's (2008)}
+#'   suggestion, rescaling the estimates by dividing them by two standard deviations
+#'   instead of just one. Resulting coefficients are then directly comparable for
+#'   untransformed binary predictors. For backward compatibility reasons,
+#'   \code{show.std} also may be a logical value; if \code{TRUE}, normal standardized
+#'   estimates are printed (same effect as \code{show.std = "std"}). Use
+#'   \code{show.std = NULL} (default) or \code{show.std = FALSE}, if no standardization
+#'   is required.
+#' }
+#' \subsection{How do I use \code{CSS}-argument?}{
 #'    With the \code{CSS}-argument, the visual appearance of the tables
 #'    can be modified. To get an overview of all style-sheet-classnames
 #'    that are used in this function, see return value \code{page.style} for details.
@@ -208,13 +228,14 @@
 #'      \item \code{css.arc = 'color:blue;'} for a blue text color each 2nd row.
 #'      \item \code{css.caption = '+color:red;'} to add red font-color to the default table caption style.
 #'    }
+#' }
 #
 #' @importFrom dplyr full_join select if_else mutate
 #' @importFrom purrr reduce map2 map_if map_df compact map_lgl map_chr flatten_chr
-#' @importFrom sjlabelled get_dv_labels get_term_labels
+#' @importFrom sjlabelled response_labels term_labels
 #' @importFrom sjmisc word_wrap var_rename add_columns add_case
 #' @importFrom insight model_info is_multivariate find_random get_data find_predictors
-#' @importFrom performance r2 icc
+#' @importFrom performance r2 variance_decomposition
 #' @importFrom stats nobs setNames
 #' @importFrom rlang .data
 #' @importFrom utils packageVersion
@@ -249,6 +270,8 @@ tab_model <- function(
   terms = NULL,
   rm.terms = NULL,
   order.terms = NULL,
+  keep = NULL,
+  drop = NULL,
 
   title = NULL,
   pred.labels = NULL,
@@ -259,8 +282,9 @@ tab_model <- function(
   iterations = 1000,
   seed = NULL,
 
+  robust = FALSE,
   vcov.fun = NULL,
-  vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5"),
+  vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5", "CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3"),
   vcov.args = NULL,
 
   string.pred = "Predictors",
@@ -271,8 +295,10 @@ tab_model <- function(
   string.std_se = "standardized std. Error",
   string.std_ci = "standardized CI",
   string.p = "p",
+  string.std.p = "std. p",
   string.df = "df",
   string.stat = "Statistic",
+  string.std.stat = "std. Statistic",
   string.resp = "Response",
   string.intercept = "(Intercept)",
   strings = NULL,
@@ -294,17 +320,23 @@ tab_model <- function(
     "ci.inner",
     "ci.outer",
     "stat",
+    "std.stat",
     "p",
-    "df",
+    "std.p",
+    "df.error",
     "response.level"
   ),
 
   digits = 2,
   digits.p = 3,
+  digits.rsq = 3,
+  digits.re = 2,
   emph.p = TRUE,
-  p.val = c("wald", "kenward", "kr", "satterthwaite"),
-  p.style = c("numeric", "asterisk", "both"),
+  p.val = NULL,
+  df.method = NULL,
+  p.style = c("numeric", "stars", "numeric_stars", "scientific", "scientific_stars"),
   p.threshold = c(0.05, 0.01, 0.001),
+  p.adjust = NULL,
 
   case = "parsed",
   auto.label = TRUE,
@@ -312,19 +344,21 @@ tab_model <- function(
   bpe = "median",
   CSS = css_theme("regression"),
   file = NULL,
-  use.viewer = TRUE
+  use.viewer = TRUE,
+  encoding = "UTF-8"
 ) {
 
-  p.val <- match.arg(p.val)
+  if (!missing(df.method)) {
+    p.val <- df.method
+  }
+
+  if (!is.null(p.val)) {
+    p.val <- match.arg(p.val, choices = c("wald", "profile", "kenward", "kr", "satterthwaite", "ml1", "betwithin"))
+  }
   p.style <- match.arg(p.style)
   prefix.labels <- match.arg(prefix.labels)
   vcov.type <- match.arg(vcov.type)
 
-  ## TODO remove once parameters update is on CRAN
-  if (p.val != "wald" && utils::packageVersion("parameters") <= "0.4.1") {
-    message("Computation of Kenward-Roger or Satterthwaite approximated degrees of freedom for p-values will be inaccurate with the current version of the 'parameters' package. Please update package 'parameters' from GitHub to get reliable p-values.")
-  }
-
   change_string_est <- !missing(string.est)
 
   # if we prefix labels, use different default for case conversion,
@@ -336,7 +370,13 @@ tab_model <- function(
       case <- NULL
   }
 
-  if (p.style == "asterisk") show.p <- FALSE
+  if (p.style == "stars") show.p <- FALSE
+
+  # default robust?
+  if (isTRUE(robust)) {
+    vcov.type <- "HC3"
+    vcov.fun <- "vcovHC"
+  }
 
   # check se-argument
   vcov.fun <- check_se_argument(se = vcov.fun, type = NULL)
@@ -368,7 +408,7 @@ tab_model <- function(
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.estimate"
 
   copos <- which("std.se" == col.order)
-  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.std.error"
+  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.se"
 
   copos <- which("std.ci" == col.order)
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.conf.int"
@@ -376,9 +416,14 @@ tab_model <- function(
   copos <- which("p" == col.order)
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "p.value"
 
+  copos <- which("std.p" == col.order)
+  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.p.value"
+
   copos <- which("stat" == col.order)
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "statistic"
 
+  copos <- which("std.stat" == col.order)
+  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.statistic"
 
   # match strings, to label the default strings in the table,
   # like "Estimate", "CI" etc.
@@ -392,8 +437,10 @@ tab_model <- function(
     if ("std_se" %in% s.names) string.std_se <- strings[["std_se"]]
     if ("std_ci" %in% s.names) string.std_ci <- strings[["std_ci"]]
     if ("p" %in% s.names) string.p <- strings[["p"]]
+    if ("std.p" %in% s.names) string.std.p <- strings[["std.p"]]
     if ("df" %in% s.names) string.df <- strings[["df"]]
     if ("stat" %in% s.names) string.stat <- strings[["stat"]]
+    if ("std.stat" %in% s.names) string.std.stat <- strings[["std.stat"]]
     if ("resp" %in% s.names) string.resp <- strings[["resp"]]
     if ("intercept" %in% s.names) string.intercept <- strings[["intercept"]]
   }
@@ -412,7 +459,7 @@ tab_model <- function(
       # check whether estimates should be transformed or not
 
       if (auto.transform) {
-        if (fam.info$is_linear)
+        if (fam.info$is_linear || identical(fam.info$link_function, "identity"))
           transform <- NULL
         else
           transform <- "exp"
@@ -432,7 +479,10 @@ tab_model <- function(
         p.val = p.val,
         bootstrap = bootstrap,
         iterations = iterations,
-        seed = seed
+        seed = seed,
+        p_adjust = p.adjust,
+        keep = keep,
+        drop = drop
       )
 
 
@@ -443,6 +493,7 @@ tab_model <- function(
         dat[["estimate"]] <- funtrans(dat[["estimate"]])
         dat[["conf.low"]] <- funtrans(dat[["conf.low"]])
         dat[["conf.high"]] <- funtrans(dat[["conf.high"]])
+        dat[["std.error"]] <- dat[["std.error"]] * dat[["estimate"]]
       }
 
 
@@ -457,19 +508,7 @@ tab_model <- function(
           digits,
           .data$conf.high
         )) %>%
-        dplyr::select(-.data$conf.low, -.data$conf.high) %>%
-        dplyr::mutate(
-          p.stars = get_p_stars(.data$p.value, p.threshold),
-          p.sig = .data$p.value < .05,
-          p.value = sprintf("%.*f", digits.p, .data$p.value)
-        )
-
-
-      # emphasize p-values ----
-
-      if (emph.p && !all(dat$p.value == "NA")) dat$p.value[dat$p.sig] <- sprintf("<strong>%s</strong>", dat$p.value[dat$p.sig])
-      dat <- dplyr::select(dat, -.data$p.sig)
-
+        dplyr::select(-.data$conf.low, -.data$conf.high)
 
       # get inner probability (i.e. 2nd CI for Stan-models) ----
 
@@ -487,21 +526,11 @@ tab_model <- function(
             dplyr::select(-.data$conf.low50, -.data$conf.high50)
       }
 
-
-      # indicate p <0.001 ----
-
-      pv <- paste0("0.", paste(rep("0", digits.p), collapse = ""))
-      dat$p.value[dat$p.value == pv] <- "&lt;0.001"
-
-      pv <- paste0("<strong>0.", paste(rep("0", digits.p), collapse = ""), "</strong>")
-      dat$p.value[dat$p.value == pv] <- "<strong>&lt;0.001"
-
-
       # tidy output of standardized values ----
 
       if (!is.null(show.std) && !is.stan(model)) {
         std_method <- switch(show.std, "std" = "refit", "std2" = "2sd", "")
-        dat <- tidy_model(
+        tmp_dat <- tidy_model(
           model = model,
           ci.lvl = ci.lvl,
           tf = transform,
@@ -511,18 +540,37 @@ tab_model <- function(
           facets = FALSE,
           show.zeroinf = show.zeroinf,
           p.val = p.val,
+          p_adjust = p.adjust,
           standardize = std_method,
           bootstrap = bootstrap,
           iterations = iterations,
-          seed = seed
+          seed = seed,
+          keep = keep,
+          drop = drop
         ) %>%
+          format_p_values(p.style, digits.p, emph.p, p.threshold) %>%
           sjmisc::var_rename(
             estimate = "std.estimate",
             std.error = "std.se",
             conf.low = "std.conf.low",
-            conf.high = "std.conf.high"
+            conf.high = "std.conf.high",
+            p.value = "std.p.value",
+            statistic = "std.statistic",
+            p.stars = "std.p.stars"
           ) %>%
-          dplyr::select(-1) %>%
+          dplyr::select(-1)
+
+        # transform estimates
+
+        if (!is.stan(model) && !is.null(transform)) {
+          funtrans <- match.fun(transform)
+          tmp_dat[["std.estimate"]] <- funtrans(tmp_dat[["std.estimate"]])
+          tmp_dat[["std.conf.low"]] <- funtrans(tmp_dat[["std.conf.low"]])
+          tmp_dat[["std.conf.high"]] <- funtrans(tmp_dat[["std.conf.high"]])
+          tmp_dat[["std.se"]] <- tmp_dat[["std.se"]] * tmp_dat[["std.estimate"]]
+        }
+
+        dat <- tmp_dat %>%
           sjmisc::add_columns(dat) %>%
           dplyr::mutate(std.conf.int = sprintf(
             "%.*f%s%.*f",
@@ -533,16 +581,26 @@ tab_model <- function(
             .data$std.conf.high
           )) %>%
           dplyr::select(-.data$std.conf.low, -.data$std.conf.high)
+        # if t-statistic is the same for standardized and unstandardized model
+        # remove standardized; ignore intercept
+        if (all(round(dat$statistic[-1], 3) == round(dat$std.statistic[-1], 3))) {
+          dat <- dat %>%
+            dplyr::select(-.data$std.statistic, -.data$std.p.value)
+        }
       }
 
+      # format p values for unstandardized model
+      dat <- format_p_values(dat, p.style, digits.p, emph.p, p.threshold)
 
       # add asterisks to estimates ----
 
-      if (p.style %in% c("asterisk", "both")) {
+      if (grepl("stars", p.style)) {
         if (obj_has_name(dat, "estimate"))
           dat$estimate <- sprintf("%.*f <sup>%s</sup>", digits, dat$estimate, dat$p.stars)
-        if (!show.est && obj_has_name(dat, "std.estimate"))
-          dat$std.estimate <- sprintf("%.*f <sup>%s</sup>", digits, dat$std.estimate, dat$p.stars)
+        if (!show.est && obj_has_name(dat, "std.estimate")) {
+          dat$std.estimate <- sprintf("%.*f <sup>%s</sup>", digits, dat$std.estimate, dat$std.p.stars)
+          dat <- dplyr::select(dat, -.data$std.p.stars)
+        }
       }
 
       dat <- dplyr::select(dat, -.data$p.stars)
@@ -588,9 +646,11 @@ tab_model <- function(
 
         # for stan models, we also have 50% HDI
         if (!sjmisc::is_empty(string_starts_with("ci", x = colnames(dat)))) {
+          if (isTRUE(show.ci50)) {
+            dat <- dplyr::select(dat, -string_starts_with("ci.inner", x = colnames(dat)))
+            dat[[est.cols]] <- sprintf("%s%s(%s)", dat[[est.cols]], lb, dat[[est.cols + 2]])
+          }
           dat <- dplyr::select(dat, -string_starts_with("ci.outer", x = colnames(dat)))
-          dat[[est.cols]] <- sprintf("%s%s(%s)", dat[[est.cols]], lb, dat[[est.cols + 2]])
-          dat <- dplyr::select(dat, -string_starts_with("ci.inner", x = colnames(dat)))
         } else {
           dat <- dplyr::select(dat, -string_starts_with("conf.int", x = colnames(dat)))
         }
@@ -621,6 +681,10 @@ tab_model <- function(
       }
 
 
+      # replace minus signs
+      dat[] <- lapply(dat, function(i) gsub("-(\\d)(.*)", paste0(minus.sign, "\\1\\2"), i))
+
+
       # handle zero-inflation part ----
 
       zidat <- NULL
@@ -649,17 +713,29 @@ tab_model <- function(
       }
 
 
-      vars <- NULL
+      vars <- vars_brms <- NULL
 
       # extract variance components ----
 
       if ((show.icc || show.re.var || show.r2) && is_mixed_model(model)) {
         if (inherits(model, "brmsfit")) {
-          vars_brms <- performance::icc(model)
-          vars$var.intercept <- attr(vars_brms, "var_rand_intercept")
-          vars$var.residual <- attr(vars_brms, "var_residual")
+          vars <- suppressWarnings(insight::get_variance(model))
+          if (is.null(vars)) {
+            vars_brms <- tryCatch(
+              {
+                performance::variance_decomposition(model)
+              },
+              error = function(e) {
+                NULL
+              }
+            )
+            if (!is.null(vars_brms)) {
+              vars$var.intercept <- attr(vars_brms, "var_rand_intercept")
+              vars$var.residual <- attr(vars_brms, "var_residual")
+            }
+          }
         } else {
-          vars <- insight::get_variance(model)
+          vars <- suppressWarnings(insight::get_variance(model))
         }
       } else {
         vars <- NULL
@@ -673,7 +749,7 @@ tab_model <- function(
       icc <- NULL
 
       if (show.icc && is_mixed_model(model) && !is.null(vars) && !all(is.na(vars))) {
-        if (inherits(model, "brmsfit")) {
+        if (inherits(model, "brmsfit") && !is.null(vars_brms)) {
           icc <- list(icc.adjusted = vars_brms$ICC_decomposed)
         } else {
           icc <- list(icc.adjusted = vars$var.random / (vars$var.random + vars$var.residual))
@@ -753,7 +829,7 @@ tab_model <- function(
       if (show.aic) aic <- model_aic(model)
 
       aicc <- NULL
-      if (show.aicc) aic <- model_aicc(model)
+      if (show.aicc) aicc <- model_aicc(model)
 
       loglik <- NULL
       if (show.loglik) loglik <- model_loglik(model)
@@ -948,7 +1024,7 @@ tab_model <- function(
 
   if (isTRUE(auto.label) && sjmisc::is_empty(pred.labels)) {
     if (.labelled_model_data(models) || any(sapply(models, is.stan)) || isTRUE(show.reflvl)) {
-      pred.labels <- sjlabelled::get_term_labels(models, case = case, mark.cat = TRUE, prefix = prefix.labels)
+      pred.labels <- sjlabelled::term_labels(models, case = case, mark.cat = TRUE, prefix = prefix.labels)
       category.values <- attr(pred.labels, "category.value")
 
       # remove random effect labels
@@ -961,7 +1037,7 @@ tab_model <- function(
       ))
 
       if (!is.null(re_terms)) {
-        pred.labels.tmp <- sjlabelled::get_term_labels(models, case = case, mark.cat = TRUE, prefix = "varname")
+        pred.labels.tmp <- sjlabelled::term_labels(models, case = case, mark.cat = TRUE, prefix = "varname")
         for (.re in re_terms) {
           found <- grepl(paste0("^", .re, ":"), pred.labels.tmp)
           if (any(found)) {
@@ -1062,13 +1138,13 @@ tab_model <- function(
   }
 
 
-  if (isTRUE(auto.label) && sjmisc::is_empty(dv.labels)) {
+  if (isTRUE(auto.label) && is.null(dv.labels)) {
     dv.labels <- sjmisc::word_wrap(
-      sjlabelled::get_dv_labels(models, case = case),
+      sjlabelled::response_labels(models, case = case),
       wrap = wrap.labels,
       linesep = "<br>"
     )
-  } else if (sjmisc::is_empty(dv.labels)) {
+  } else if (is.null(dv.labels)) {
     dv.labels <- purrr::map(models, insight::find_response) %>% purrr::flatten_chr()
   }
 
@@ -1144,12 +1220,18 @@ tab_model <- function(
     pos <- grep("^p.value", x)
     if (!sjmisc::is_empty(pos)) x <- string.p
 
+    pos <- grep("^std.p.value", x)
+    if (!sjmisc::is_empty(pos)) x <- string.std.p
+
     pos <- grep("^df", x)
     if (!sjmisc::is_empty(pos)) x <- string.df
 
     pos <- grep("^statistic", x)
     if (!sjmisc::is_empty(pos)) x <- string.stat
 
+    pos <- grep("^std.statistic", x)
+    if (!sjmisc::is_empty(pos)) x <- string.std.stat
+
     pos <- grep("^response.level", x)
     if (!sjmisc::is_empty(pos)) x <- string.resp
 
@@ -1163,7 +1245,7 @@ tab_model <- function(
   })
 
 
-  if (p.style %in% c("asterisk", "both"))
+  if (grepl("stars", p.style))
     footnote <- sprintf(
       "* p&lt;%s&nbsp;&nbsp;&nbsp;** p&lt;%s&nbsp;&nbsp;&nbsp;*** p&lt;%s",
       format(p.threshold[1]),
@@ -1196,7 +1278,10 @@ tab_model <- function(
     CSS = CSS,
     file = file,
     use.viewer = use.viewer,
-    footnote = footnote
+    footnote = footnote,
+    digits.rsq = digits.rsq,
+    digits.re = digits.re,
+    encoding = encoding
   )
 }
 
@@ -1218,7 +1303,7 @@ sort_columns <- function(x, is.stan, col.order) {
     "ci.outer",
     "statistic",
     "p.value",
-    "df",
+    "df.error",
     "wrap.facet",
     "response.level"
   )
@@ -1283,7 +1368,8 @@ remove_unwanted <- function(dat, show.intercept, show.est, show.std, show.ci, sh
   }
 
   if (show.stat == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("statistic", x = colnames(dat)))
+    dat <- dplyr::select(dat, -string_starts_with("statistic", x = colnames(dat)),
+                         -string_starts_with("std.statistic", x = colnames(dat)))
   }
 
   if (show.response == FALSE) {
@@ -1291,7 +1377,8 @@ remove_unwanted <- function(dat, show.intercept, show.est, show.std, show.ci, sh
   }
 
   if (show.p == FALSE) {
-    dat <- dplyr::select(dat, -string_starts_with("p.value", x = colnames(dat)))
+    dat <- dplyr::select(dat, -string_starts_with("p.value", x = colnames(dat)),
+                         -string_starts_with("std.p.value", x = colnames(dat)))
   }
 
   if (show.df == FALSE) {
@@ -1300,14 +1387,14 @@ remove_unwanted <- function(dat, show.intercept, show.est, show.std, show.ci, sh
 
   if (!is.null(terms)) {
     terms <- parse_terms(terms)
-    keep <- which(dat$term %in% terms)
-    dat <- dplyr::slice(dat, !! keep)
+    keep_terms <- which(dat$term %in% terms)
+    dat <- dplyr::slice(dat, !! keep_terms)
   }
 
   if (!is.null(rm.terms)) {
     rm.terms <- parse_terms(rm.terms)
-    keep <- which(!(dat$term %in% rm.terms))
-    dat <- dplyr::slice(dat, !! keep)
+    keep_terms <- which(!(dat$term %in% rm.terms))
+    dat <- dplyr::slice(dat, !! keep_terms)
   }
 
   dat
@@ -1342,3 +1429,35 @@ prepare.labels <- function(x, grp, categorical, models) {
 
   x
 }
+
+format_p_values <- function(dat, p.style, digits.p, emph.p, p.threshold){
+  # get stars and significance at alpha = 0.05 ----
+
+  dat <- dat %>%
+    dplyr::mutate(
+    p.stars = get_p_stars(.data$p.value, p.threshold),
+    p.sig = .data$p.value < .05
+  )
+
+  # scientific notation ----
+
+  if (grepl("scientific", p.style)) {
+    dat$p.value <- formatC(dat$p.value, format = "e", digits = digits.p)
+  } else {
+    dat$p.value <- sprintf("%.*f", digits.p, dat$p.value)
+  }
+
+  # emphasize p-values ----
+
+  if (emph.p && !all(dat$p.value == "NA")) dat$p.value[which(dat$p.sig)] <- sprintf("<strong>%s</strong>", dat$p.value[which(dat$p.sig)])
+  dat <- dplyr::select(dat, -.data$p.sig)
+
+  # indicate p <0.001 ----
+
+  pv <- paste0("0.", paste(rep("0", digits.p), collapse = ""))
+  dat$p.value[dat$p.value == pv] <- "&lt;0.001"
+
+  pv <- paste0("<strong>0.", paste(rep("0", digits.p), collapse = ""), "</strong>")
+  dat$p.value[dat$p.value == pv] <- "<strong>&lt;0.001</strong>"
+  dat
+}
