@@ -89,7 +89,8 @@
 #'                           css.summary = "font-style:italic;"))
 #' }
 #' }
-#' @importFrom parameters skewness kurtosis
+#' @importFrom parameters kurtosis
+#' @importFrom datawizard skewness
 #' @importFrom sjmisc frq
 #' @export
 tab_stackfrq <- function(items,
@@ -181,8 +182,8 @@ tab_stackfrq <- function(items,
   # ----------------------------
   # additional statistics required from psych-package?
   # ----------------------------
-  if (show.skew) pstat_skewness <- parameters::skewness(items)
-  if (show.kurtosis) pstat_kurtosis <- parameters::kurtosis(items)
+  if (show.skew) pstat_skewness <- datawizard::skewness(items)
+  if (show.kurtosis) pstat_kurtosis <- datawizard::kurtosis(items)
   if (is.null(weight.by)) {
     dummy <- sjmisc::frq(items, show.strings = TRUE, show.na = show.na)
   } else {
