@@ -15,6 +15,14 @@ knitr::opts_chunk$set(
 )
 options(width = 800, tibble.width = Inf)
 
+if (!requireNamespace("sjmisc", quietly = TRUE) ||
+    !requireNamespace("splines", quietly = TRUE) ||
+    !requireNamespace("ggplot2", quietly = TRUE) ||
+    !requireNamespace("sjlabelled", quietly = TRUE)) {
+  knitr::opts_chunk$set(eval = FALSE)
+}
+
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 library(sjPlot)
 library(ggplot2)
